package javax.swing.event;

import javax.swing.SwingUtilities;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeSupport;

public final class SwingPropertyChangeSupport extends PropertyChangeSupport
{
    static final long serialVersionUID = 7162625831330845068L;
    private final boolean notifyOnEDT;
    
    public SwingPropertyChangeSupport(Object o) {
        this(o, false);
    }
    
    public SwingPropertyChangeSupport(Object sourceBean, boolean notifyOnEDT) {
        super(sourceBean);
        this.notifyOnEDT = notifyOnEDT;
    }
    
    @Override
    public void firePropertyChange(final PropertyChangeEvent event) {
        if (event == null) {
            throw new NullPointerException();
        }
        if (!this.isNotifyOnEDT() || SwingUtilities.isEventDispatchThread()) {
            super.firePropertyChange(event);
        }
        else {
            SwingUtilities.invokeLater(new Runnable() {
                @Override
                public void run() {
                    SwingPropertyChangeSupport.this.firePropertyChange(event);
                }
            });
        }
        return;
    }
    
    public final boolean isNotifyOnEDT() {
        return this.notifyOnEDT;
    }
}
